@@ -22,7 +22,7 @@ C<Sys::IO> is the class for the file IO.
 
 Given a pathname for a file, open() returns a file descriptor, a small, nonnegative integer for use in subsequent system calls (read(2), write(2), lseek(2), fcntl(2), etc.). The file descriptor returned by a successful call will be the lowest-numbered file descriptor not currently open for the process.
 
-See the detail of the L<open|https://linux.die.net/man/2/open> function in the case of Linux.
+See the L<open|https://linux.die.net/man/2/open> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the flags and the mode.
 
@@ -32,7 +32,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 read() attempts to read up to count bytes from file descriptor fd into the buffer starting at buf.
 
-See the detail of the L<read|https://linux.die.net/man/2/read> function in the case of Linux.
+See the L<read|https://linux.die.net/man/2/read> function in Linux.
 
 =head2 write
 
@@ -40,7 +40,7 @@ See the detail of the L<read|https://linux.die.net/man/2/read> function in the c
 
 write() writes up to count bytes from the buffer pointed buf to the file referred to by the file descriptor fd.
 
-See the detail of the L<write|https://linux.die.net/man/2/write> function in the case of Linux.
+See the L<write|https://linux.die.net/man/2/write> function in Linux.
 
 =head2 lseek
 
@@ -48,7 +48,7 @@ See the detail of the L<write|https://linux.die.net/man/2/write> function in the
 
 The lseek() function repositions the offset of the open file associated with the file descriptor fd to the argument offset according to the directive whence as follows:
 
-See the detail of the L<lseek|https://linux.die.net/man/2/lseek> function in the case of Linux.
+See the L<lseek|https://linux.die.net/man/2/lseek> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the whence.
 
@@ -58,7 +58,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 close() closes a file descriptor, so that it no longer refers to any file and may be reused. Any record locks (see fcntl(2)) held on the file it was associated with, and owned by the process, are removed (regardless of the file descriptor that was used to obtain the lock).
 
-See the detail of the L<close|https://linux.die.net/man/2/close> function in the case of Linux.
+See the L<close|https://linux.die.net/man/2/close> function in Linux.
 
 =head2 fopen
 
@@ -66,7 +66,7 @@ See the detail of the L<close|https://linux.die.net/man/2/close> function in the
 
 The fopen() function opens the file whose name is the string pointed to by path and associates a stream with it.
 
-See the detail of the L<fopen|https://linux.die.net/man/3/fopen> function in the case of Linux.
+See the L<fopen|https://linux.die.net/man/3/fopen> function in Linux.
 
 The return value is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
@@ -76,7 +76,7 @@ The return value is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 The fdopen() function associates a stream with the existing file descriptor, fd. The mode of the stream (one of the values "r", "r+", "w", "w+", "a", "a+") must be compatible with the mode of the file descriptor. The file position indicator of the new stream is set to that belonging to fd, and the error and end-of-file indicators are cleared. Modes "w" or "w+" do not cause truncation of the file. The file descriptor is not dup'ed, and will be closed when the stream created by fdopen() is closed. The result of applying fdopen() to a shared memory object is undefined.
 
-See the detail of the L<fdopen|https://linux.die.net/man/3/fdopen> function in the case of Linux.
+See the L<fdopen|https://linux.die.net/man/3/fdopen> function in Linux.
 
 The return value is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
@@ -86,7 +86,7 @@ The return value is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 The function fileno() examines the argument stream and returns its integer descriptor.
 
-See the detail of the L<fileno|https://linux.die.net/man/3/fileno> function in the case of Linux.
+See the L<fileno|https://linux.die.net/man/3/fileno> function in Linux.
 
 The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
@@ -96,7 +96,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 The function fread() reads nmemb elements of data, each size bytes long, from the stream pointed to by stream, storing them at the location given by ptr.
 
-See the detail of the L<fread|https://linux.die.net/man/3/fread> function in the case of Linux.
+See the L<fread|https://linux.die.net/man/3/fread> function in Linux.
 
 =head2 feof
 
@@ -104,7 +104,7 @@ See the detail of the L<fread|https://linux.die.net/man/3/fread> function in the
 
 The function feof() tests the end-of-file indicator for the stream pointed to by stream, returning nonzero if it is set. The end-of-file indicator can only be cleared by the function clearerr().
 
-See the detail of the L<feof|https://linux.die.net/man/3/feof> function in the case of Linux.
+See the L<feof|https://linux.die.net/man/3/feof> function in Linux.
 
 The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
@@ -114,7 +114,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 The function ferror() tests the error indicator for the stream pointed to by stream, returning nonzero if it is set. The error indicator can only be reset by the clearerr() function.
 
-See the detail of the L<ferror|https://linux.die.net/man/3/ferror> function in the case of Linux.
+See the L<ferror|https://linux.die.net/man/3/ferror> function in Linux.
 
 The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
@@ -124,7 +124,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 The function clearerr() clears the end-of-file and error indicators for the stream pointed to by stream.
 
-See the detail of the L<clearerr|https://linux.die.net/man/3/clearerr> function in the case of Linux.
+See the L<clearerr|https://linux.die.net/man/3/clearerr> function in Linux.
 
 The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
@@ -134,7 +134,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 getc() is equivalent to fgetc() except that it may be implemented as a macro which evaluates stream more than once.
 
-See the detail of the L<getc|https://linux.die.net/man/3/getc> function in the case of Linux.
+See the L<getc|https://linux.die.net/man/3/getc> function in Linux.
 
 The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
@@ -144,7 +144,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 fgets() reads in at most one less than size characters from stream and stores them into the buffer pointed to by s. Reading stops after an EOF or a newline. If a newline is read, it is stored into the buffer. A terminating null byte (aq\0aq) is stored after the last character in the buffer.
 
-See the detail of the L<fgets|https://linux.die.net/man/3/fgets> function in the case of Linux.
+See the L<fgets|https://linux.die.net/man/3/fgets> function in Linux.
 
 =head2 fwrite
 
@@ -152,7 +152,7 @@ See the detail of the L<fgets|https://linux.die.net/man/3/fgets> function in the
 
 The function fwrite() writes nmemb elements of data, each size bytes long, to the stream pointed to by stream, obtaining them from the location given by ptr.
 
-See the detail of the L<fread|https://linux.die.net/man/3/fwrite> function in the case of Linux.
+See the L<fread|https://linux.die.net/man/3/fwrite> function in Linux.
 
 The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
@@ -162,7 +162,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 The fseek() function sets the file position indicator for the stream pointed to by stream. The new position, measured in bytes, is obtained by adding offset bytes to the position specified by whence. If whence is set to SEEK_SET, SEEK_CUR, or SEEK_END, the offset is relative to the start of the file, the current position indicator, or end-of-file, respectively. A successful call to the fseek() function clears the end-of-file indicator for the stream and undoes any effects of the ungetc(3) function on the same stream.
 
-See the detail of the L<fseek|https://linux.die.net/man/3/fseek> function in the case of Linux.
+See the L<fseek|https://linux.die.net/man/3/fseek> function in Linux.
 
 The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
@@ -174,7 +174,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 The ftell() function obtains the current value of the file position indicator for the stream pointed to by stream.
 
-See the detail of the L<ftell|https://linux.die.net/man/3/ftell> function in the case of Linux.
+See the L<ftell|https://linux.die.net/man/3/ftell> function in Linux.
 
 The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
@@ -184,7 +184,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 The fclose() function flushes the stream pointed to by fp (writing any buffered output data using fflush(3)) and closes the underlying file descriptor.
 
-See the detail of the L<fclose|https://linux.die.net/man/3/fclose> function in the case of Linux.
+See the L<fclose|https://linux.die.net/man/3/fclose> function in Linux.
 
 The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
@@ -194,7 +194,7 @@ The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
 
 For output streams, fflush() forces a write of all user-space buffered data for the given output or update stream via the stream's underlying write function. For input streams, fflush() discards any buffered data that has been fetched from the underlying file, but has not been consumed by the application. The open status of the stream is unaffected.
 
-See the detail of the L<fflush|https://linux.die.net/man/3/fflush> function in the case of Linux.
+See the L<fflush|https://linux.die.net/man/3/fflush> function in Linux.
 
 =head2 flock
 
@@ -202,7 +202,7 @@ See the detail of the L<fflush|https://linux.die.net/man/3/fflush> function in t
 
 Apply or remove an advisory lock on the open file specified by fd. The argument operation is one of the following:
 
-See the detail of the L<flock|https://linux.die.net/man/2/flock> function in the case of Linux.
+See the L<flock|https://linux.die.net/man/2/flock> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the operation.
 
@@ -212,7 +212,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 mkdir() attempts to create a directory named pathname.
 
-See the detail of the L<mkdir|https://linux.die.net/man/2/mkdir> function in the case of Linux.
+See the L<mkdir|https://linux.die.net/man/2/mkdir> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the mode.
 
@@ -222,7 +222,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 umask() sets the calling process's file mode creation mask (umask) to mask & 0777 (i.e., only the file permission bits of mask are used), and returns the previous value of the mask.
 
-See the detail of the L<umask|https://linux.die.net/man/2/umask> function in the case of Linux.
+See the L<umask|https://linux.die.net/man/2/umask> function in Linux.
 
 =head2 rmdir
 
@@ -230,7 +230,7 @@ See the detail of the L<umask|https://linux.die.net/man/2/umask> function in the
 
 rmdir() deletes a directory, which must be empty.
 
-See the detail of the L<rmdir|https://linux.die.net/man/2/rmdir> function in the case of Linux.
+See the L<rmdir|https://linux.die.net/man/2/rmdir> function in Linux.
 
 =head2 unlink
 
@@ -238,7 +238,7 @@ See the detail of the L<rmdir|https://linux.die.net/man/2/rmdir> function in the
 
 unlink() deletes a name from the file system. If that name was the last link to a file and no processes have the file open the file is deleted and the space it was using is made available for reuse.
 
-See the detail of the L<unlink|https://linux.die.net/man/2/unlink> function in the case of Linux.
+See the L<unlink|https://linux.die.net/man/2/unlink> function in Linux.
 
 =head2 rename
 
@@ -246,7 +246,7 @@ See the detail of the L<unlink|https://linux.die.net/man/2/unlink> function in t
 
 rename() renames a file, moving it between directories if required. Any other hard links to the file (as created using link(2)) are unaffected. Open file descriptors for oldpath are also unaffected.
 
-See the detail of the L<rename|https://linux.die.net/man/2/rename> function in the case of Linux.
+See the L<rename|https://linux.die.net/man/2/rename> function in Linux.
 
 =head2 getcwd
 
@@ -254,7 +254,7 @@ See the detail of the L<rename|https://linux.die.net/man/2/rename> function in t
 
 The getcwd() function copies an absolute pathname of the current working directory to the array pointed to by buf, which is of length size.
 
-See the detail of the L<getcwd|https://linux.die.net/man/2/getcwd> function in the case of Linux.
+See the L<getcwd|https://linux.die.net/man/2/getcwd> function in Linux.
 
 =head2 _getdcwd
 
@@ -262,7 +262,7 @@ See the detail of the L<getcwd|https://linux.die.net/man/2/getcwd> function in t
 
 Gets the full path of the current working directory on the specified drive.
 
-See the detail of the L<_getdcwd|https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/getdcwd-wgetdcwd?view=msvc-170> function in the case of Windows.
+See the L<_getdcwd|https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/getdcwd-wgetdcwd?view=msvc-170> function in the case of Windows.
 
 =head2 realpath
 
@@ -270,7 +270,7 @@ See the detail of the L<_getdcwd|https://docs.microsoft.com/en-us/cpp/c-runtime-
 
 realpath() expands all symbolic links and resolves references to /./, /../ and extra '/' characters in the null-terminated string named by path to produce a canonicalized absolute pathname. The resulting pathname is stored as a null-terminated string, up to a maximum of PATH_MAX bytes, in the buffer pointed to by resolved_path. The resulting path will have no symbolic link, /./ or /../ components.
 
-See the detail of the L<realpath|https://linux.die.net/man/3/realpath> function in the case of Linux.
+See the L<realpath|https://linux.die.net/man/3/realpath> function in Linux.
 
 =head2 _fullpath
 
@@ -278,7 +278,7 @@ See the detail of the L<realpath|https://linux.die.net/man/3/realpath> function
 
 Creates an absolute or full path name for the specified relative path name.
 
-See the detail of the L<_fullpath|https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/fullpath-wfullpath?view=msvc-170> function in the case of Windows.
+See the L<_fullpath|https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/fullpath-wfullpath?view=msvc-170> function in the case of Windows.
 
 =head2 chdir
 
@@ -286,7 +286,7 @@ See the detail of the L<_fullpath|https://docs.microsoft.com/en-us/cpp/c-runtime
 
 chdir() changes the current working directory of the calling process to the directory specified in path.
 
-See the detail of the L<chdir|https://linux.die.net/man/2/chdir> function in the case of Linux.
+See the L<chdir|https://linux.die.net/man/2/chdir> function in Linux.
 
 =head2 chmod
 
@@ -294,7 +294,7 @@ See the detail of the L<chdir|https://linux.die.net/man/2/chdir> function in the
 
 chmod() changes the permissions of the file specified whose pathname is given in path, which is dereferenced if it is a symbolic link.
 
-See the detail of the L<chmod|https://linux.die.net/man/2/chmod> function in the case of Linux.
+See the L<chmod|https://linux.die.net/man/2/chmod> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the mode.
 
@@ -304,7 +304,7 @@ See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for th
 
 chown() changes the ownership of the file specified by path, which is dereferenced if it is a symbolic link.
 
-See the detail of the L<chown|https://linux.die.net/man/2/chown> function in the case of Linux.
+See the L<chown|https://linux.die.net/man/2/chown> function in Linux.
 
 =head2 truncate
 
@@ -312,7 +312,7 @@ See the detail of the L<chown|https://linux.die.net/man/2/chown> function in the
 
 The truncate() and ftruncate() functions cause the regular file named by path or referenced by fd to be truncated to a size of precisely length bytes.
 
-See the detail of the L<truncate|https://linux.die.net/man/2/truncate> function in the case of Linux.
+See the L<truncate|https://linux.die.net/man/2/truncate> function in Linux.
 
 =head2 symlink
 
@@ -320,7 +320,7 @@ See the detail of the L<truncate|https://linux.die.net/man/2/truncate> function
 
 symlink() creates a symbolic link named newpath which contains the string oldpath.
 
-See the detail of the L<symlink|https://linux.die.net/man/2/symlink> function in the case of Linux.
+See the L<symlink|https://linux.die.net/man/2/symlink> function in Linux.
 
 =head2 readlink
 
@@ -328,7 +328,7 @@ See the detail of the L<symlink|https://linux.die.net/man/2/symlink> function in
 
 readlink() places the contents of the symbolic link path in the buffer buf, which has size bufsiz. readlink() does not append a null byte to buf. It will truncate the contents (to a length of bufsiz characters), in case the buffer is too small to hold all of the contents.
 
-See the detail of the L<readlink|https://linux.die.net/man/2/readlink> function in the case of Linux.
+See the L<readlink|https://linux.die.net/man/2/readlink> function in Linux.
 
 =head2 opendir
 
@@ -336,7 +336,7 @@ See the detail of the L<readlink|https://linux.die.net/man/2/readlink> function
 
 The opendir() function opens a directory stream corresponding to the directory name, and returns a pointer to the directory stream. The stream is positioned at the first entry in the directory.
 
-See the detail of the L<opendir|https://linux.die.net/man/3/opendir> function in the case of Linux.
+See the L<opendir|https://linux.die.net/man/3/opendir> function in Linux.
 
 The return value is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
@@ -346,7 +346,7 @@ The return value is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
 The closedir() function closes the directory stream associated with dirp. A successful call to closedir() also closes the underlying file descriptor associated with dirp. The directory stream descriptor dirp is not available after this call.
 
-See the detail of the L<closedir|https://linux.die.net/man/3/closedir> function in the case of Linux.
+See the L<closedir|https://linux.die.net/man/3/closedir> function in Linux.
 
 The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
@@ -356,7 +356,7 @@ The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
 The readdir() function returns a pointer to a dirent structure representing the next directory entry in the directory stream pointed to by dirp. It returns NULL on reaching the end of the directory stream or if an error occurred.
 
-See the detail of the L<readdir|https://linux.die.net/man/3/readdir> function in the case of Linux.
+See the L<readdir|https://linux.die.net/man/3/readdir> function in Linux.
 
 The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
@@ -367,7 +367,7 @@ The return value is a L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent> object.
 
 The rewinddir() function resets the position of the directory stream dirp to the beginning of the directory.
 
-See the detail of the L<rewinddir|https://linux.die.net/man/3/rewinddir> function in the case of Linux.
+See the L<rewinddir|https://linux.die.net/man/3/rewinddir> function in Linux.
 
 The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
@@ -377,7 +377,7 @@ The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
 The telldir() function returns the current location associated with the directory stream dirp.
 
-See the detail of the L<telldir|https://linux.die.net/man/3/telldir> function in the case of Linux.
+See the L<telldir|https://linux.die.net/man/3/telldir> function in Linux.
 
 The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
@@ -386,7 +386,7 @@ The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
   static method seekdir : void ($dir_stream : Sys::IO::DirStream, $offset : long);
 
 The seekdir() function sets the location in the directory stream from which the next readdir(2) call will start. seekdir() should be used with an offset returned by telldir(3).
-See the detail of the L<seekdir|https://linux.die.net/man/3/seekdir> function in the case of Linux.
+See the L<seekdir|https://linux.die.net/man/3/seekdir> function in Linux.
 
 The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
@@ -396,20 +396,60 @@ The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
 The utime() system call changes the access and modification times of the inode specified by filename to the actime and modtime fields of times respectively.
 
-See the detail of the L<utime|https://linux.die.net/man/2/utime> function in the case of Linux.
+See the L<utime|https://linux.die.net/man/2/utime> function in Linux.
 
 The buffer is a L<Sys::IO::Utimbuf|SPVM::Sys::IO::Utimbuf> object.
 
+=head2 access_raw
+
+  static method access_raw : int ($pathname : string, $mode : int);
+
+The same as L</"access">, but even if the return value is C<-1>, an exception will be not thrown.
+
 =head2 access
 
-  static method access : int ($path : string, $mode : int);
+  static method access : int ($pathname : string, $mode : int);
 
 access() checks whether the calling process can access the file pathname. If pathname is a symbolic link, it is dereferenced.
 
-See the detail of the L<access|https://linux.die.net/man/2/access> function in the case of Linux.
+See the L<access|https://linux.die.net/man/2/access> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the mode.
 
+=head2 eaccess_raw
+
+  static method eaccess_raw : int ($pathname : string, $mode : int);
+
+The same as L</"eaccess">, but even if the return value is C<-1>, an exception will be not thrown.
+
+=head2 eaccess
+
+  static method eaccess : int ($pathname : string, $mode : int);
+
+eaccess() checks whether the calling process can eaccess the file pathname. If pathname is a symbolic link, it is dereferenced.
+
+See the L<eaccess|https://linux.die.net/man/3/eaccess> function in Linux.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the C<$mode>.
+
+=head2 eaccess_emulate_raw
+
+  static method eaccess_emulate : int ($pathname : string, $mode : int)
+
+The same as L</"eaccess_emulate">, but even if the return value is C<-1>, an exception will be not thrown.
+
+=head2 eaccess_emulate
+
+  static method eaccess_emulate : int ($pathname : string, $mode : int)
+
+Emulates C<eaccess> using L</"faccessat">.
+
+=head2 stat_raw
+
+  static method stat_raw : int ($path : string, $stat : Sys::IO::Stat);
+
+The same as L</"stat">, but even if the return value is C<-1>, an exception will be not thrown.
+
 =head2 stat
 
   static method stat : int ($path : string, $stat : Sys::IO::Stat);
@@ -418,10 +458,16 @@ These functions return information about a file. No permissions are required on
 
 stat() stats the file pointed to by path and fills in buf.
 
-See the detail of the L<stat|https://linux.die.net/man/2/stat> function in the case of Linux.
+See the L<stat|https://linux.die.net/man/2/stat> function in Linux.
 
 The stat is L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
+=head2 lstat_raw
+
+  static method lstat_raw : int ($path : string, $stat : Sys::IO::Stat);
+
+The same as L</"lstat">, but even if the return value is C<-1>, an exception will be not thrown.
+
 =head2 lstat
 
   static method lstat : int ($path : string, $stat : Sys::IO::Stat);
@@ -430,7 +476,7 @@ These functions return information about a file. No permissions are required on
 
 lstat() is identical to stat(), except that if path is a symbolic link, then the link itself is stat-ed, not the file that it refers to.
 
-See the detail of the L<lstat|https://linux.die.net/man/2/lstat> function in the case of Linux.
+See the L<lstat|https://linux.die.net/man/2/lstat> function in Linux.
 
 The stat is L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
@@ -440,24 +486,6 @@ The stat is L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
 fcntl() performs one of the operations described below on the open file descriptor fd. The operation is determined by cmd.
 
-See the detail of the L<lstat|https://linux.die.net/man/2/fcntl> function in the case of Linux.
+See the L<lstat|https://linux.die.net/man/2/fcntl> function in Linux.
 
 The command argument can receive a L<Sys::IO::Flock|SPVM::Sys::IO::Flock> object.
-
-=head2 ioctl
-
-  static method ioctl : int ($fd : int, $request : int, $request_arg_ref = undef : object of Byte|Short|Int|Long|Float|Double|object);
-
-The ioctl() function manipulates the underlying device parameters of special files. In particular, many operating characteristics of character special files (e.g., terminals) may be controlled with ioctl() requests. The argument d must be an open file descriptor.
-
-See the detail of the L<ioctl|https://linux.die.net/man/2/ioctl> function in the case of Linux.
-
-=head2 poll
-
-  static method poll : int ($fds : Sys::IO::PollfdArray, $nfds : int, $timeout : int);
-
-poll() performs a similar task to select(2): it waits for one of a set of file descriptors to become ready to perform I/O.
-
-See the detail of the L<poll|https://linux.die.net/man/2/poll> function in the case of Linux.
-
-The file discritors are a L<Sys::IO::PollfdArray|SPVM::Sys::IO::PollfdArray> object.
